@@ -1,10 +1,14 @@
 from __future__ import with_statement
 import re
 from fabric.api import *
-from fabric.contrib.files import append
+from fabric.contrib import files
+
+from fab_deploy import utils
+from fab_deploy import system
+
+
+__all__ = ['touch']
 
-from fab_deploy.utils import run_as, upload_config_template
-from fab_deploy.system import aptitude_install
 
 APACHE_PORTS_FILE = '/etc/apache2/ports.conf'
 APACHE_FIRST_PORT = 50000 # see http://www.iana.org/assignments/port-numbers
@@ -21,9 +25,9 @@ def apache_make_wsgi():
     wsgi_dir = env.conf['ENV_DIR']+'/var/wsgi/'
     run('mkdir -p ' + wsgi_dir)
     file_name = env.conf['INSTANCE_NAME']+'.py'
-    upload_config_template('django_wsgi.py', wsgi_dir+file_name)
+    utils.upload_config_template('django_wsgi.py', wsgi_dir+file_name)
 
-@run_as('root')
+@utils.run_as('root')
 def apache_restart():
     """ Restarts apache using init.d script. """
     # restart is not used because it can leak memory in some cases
@@ -32,20 +36,20 @@ def apache_restart():
 
 # ==== installation ===
 
-@run_as('root')
+@utils.run_as('root')
 def apache_install():
     """ Installs apache. """
-    aptitude_install('apache2 libapache2-mod-wsgi libapache2-mod-rpaf')
+    system.aptitude_install('apache2 libapache2-mod-wsgi libapache2-mod-rpaf')
     run('rm -f /etc/apache2/sites-enabled/default')
     run('rm -f /etc/apache2/sites-enabled/000-default')
     apache_setup_locale()
 
-@run_as('root')
+@utils.run_as('root')
 def apache_make_config():
     """ Updates apache config. """
     _apache_setup_port()
     name = env.conf['INSTANCE_NAME']
-    upload_config_template('apache.config', '/etc/apache2/sites-available/%s' % name)
+    utils.upload_config_template('apache.config', '/etc/apache2/sites-available/%s' % name)
     run('a2ensite %s' % name)
 
 def apache_setup():
@@ -54,22 +58,22 @@ def apache_setup():
     apache_make_wsgi()
     apache_restart()
 
-@run_as('root')
+@utils.run_as('root')
 def apache_setup_locale():
     """ Setups apache locale. Apache is unable to handle file uploads with
     unicode file names without this. """
-    append('/etc/apache2/envvars', [
+    files.append('/etc/apache2/envvars', [
             'export LANG="en_US.UTF-8"', 'export LC_ALL="en_US.UTF-8"'])
 
 # === automatic apache ports management ===
 
-@run_as('root')
+@utils.run_as('root')
 def _ports_lines():
     with (settings(hide('stdout'))):
         ports_data = run('cat ' + APACHE_PORTS_FILE)
     return ports_data.splitlines()
 
-@run_as('root')
+@utils.run_as('root')
 def _used_ports(lines):
     ports_mapping = dict()
 
@@ -87,7 +91,7 @@ def _used_ports(lines):
             ports_mapping[match.group('port')] = instance
     return ports_mapping
 
-@run_as('root')
+@utils.run_as('root')
 def _apache_setup_port():
     """
     Makes sure some port is correctly listened in
