@@ -1,12 +1,17 @@
 from __future__ import with_statement
 import os
+import posixpath
 import pprint
 from re import match
 from functools import wraps
-from fabric.contrib.files import upload_template
 from fabric.api import *
-from fabric.state import _AttributeDict
-from fabric.network import normalize, join_host_strings
+from fabric.contrib import files
+from fabric import state
+from fabric import network
+
+
+__all__ = ['run_as', 'update_env', 'inside_project', 'inside_virtualenv',
+           'delete_pyc', 'print_env', 'detect_os']
 
 def _codename(distname, version, id):
     patterns = [
@@ -42,25 +47,28 @@ def run_as(user):
     def decorator(func):
         @wraps(func)
         def inner(*args, **kwargs):
-            old_user, host, port = normalize(env.host_string)
-            env.host_string = join_host_strings(user, host, port)
+            old_user, host, port = network.normalize(env.host_string)
+            env.host_string = network.join_host_strings(user, host, port)
             result = func(*args, **kwargs)
-            env.host_string = join_host_strings(old_user, host, port)
+            env.host_string = network.join_host_strings(old_user, host, port)
             return result
         return inner
     return decorator
 
-def upload_config_template(name, to=None):
+def upload_config_template(name, to=None, check_existence=False):
     if to is None:
         base_dir = env.conf['ENV_DIR'] + "/etc/"
         run('mkdir -p ' + base_dir)
         to = base_dir + name
-    upload_template('./config_templates/' + name, to, env.conf, True)
+    config_template = _config_template_path(name)
+    if check_existence and not os.path.exists(config_template):
+        return
+    files.upload_template(config_template, to, env.conf, True)
 
 def update_env():
     """
     Updates :attr:`env.conf` configuration with some defaults and converts
-    it to _AttributeDict (that's a dictionary subclass enabling attribute
+    it to state._AttributeDict (that's a dictionary subclass enabling attribute
     lookup/assignment of keys/values).
 
     Call :func:`update_env` at the end of each server-configuring function.
@@ -77,36 +85,50 @@ def update_env():
             update_env()
     """
     assert len(env.hosts)==1, "Multiple hosts in env.hosts are not supported now. (%s)" % env.hosts
-    user, host, port = normalize(env.hosts[0])
+    user, host, port = network.normalize(env.hosts[0])
 
     env.conf = getattr(env, 'conf', {})
+    env.conf.setdefault('INSTANCE_NAME', user)
+    env.conf.setdefault('PROJECT_PATH', '')
 
     HOME_DIR = '/home/%s' % user
-    if 'INSTANCE_NAME' not in env.conf:
-        env.conf['INSTANCE_NAME'] = user
+    SRC_DIR = posixpath.join(HOME_DIR, 'src', env.conf['INSTANCE_NAME'])
+    PROJECT_DIR = posixpath.join(SRC_DIR, env.conf['PROJECT_PATH']).rstrip('/')
 
-    defaults = _AttributeDict(
-        HG_BRANCH = 'default',
-        DB_NAME = env.conf['INSTANCE_NAME'],
-        DB_USER = 'root',
-        PROCESSES = 1,
-        THREADS = 15,
-        SERVER_NAME = host,
-        SERVER_ADMIN = 'example@example.com',
-        VCS = 'hg',
+    defaults = state._AttributeDict(
+        HG_BRANCH='default',
+        GIT_BRANCH = 'master',
+        DB_NAME=env.conf['INSTANCE_NAME'],
+        DB_USER='root',
+        PROCESSES=1,
+        THREADS=15,
+        SERVER_NAME=host,
+        SERVER_ADMIN='example@example.com',
+        VCS='hg',
+
+        PROJECT_PATH='',
+        LOCAL_CONFIG='config.py',
+        REMOTE_CONFIG_TEMPLATE='config.server.py',
+        CONFIG_TEMPLATES_PATHS=['config_templates'],
+
+        PIP_REQUIREMENTS_PATH='reqs',
+        PIP_REQUIREMENTS='all.txt',
+        PIP_REQUIREMENTS_ACTIVE = 'active.txt',
 
         # these options shouldn't be set by user
-        HOME_DIR = HOME_DIR,
-        ENV_DIR = HOME_DIR + '/envs/' + env.conf['INSTANCE_NAME'],
-        SRC_DIR = HOME_DIR + '/src/' + env.conf['INSTANCE_NAME'],
-        USER = user,
+        HOME_DIR=HOME_DIR,
+        ENV_DIR=posixpath.join(HOME_DIR, 'envs', env.conf['INSTANCE_NAME']),
+        SRC_DIR=SRC_DIR,
+        PROJECT_DIR = PROJECT_DIR,
+        USER=user,
     )
     defaults.update(env.conf)
+
     env.conf = defaults
 
-    for vcs in ['hg', 'none']: # expand VCS name to full import path
+    for vcs in ['git', 'hg', 'none']: # expand VCS name to full import path
         if env.conf.VCS == vcs:
-            env.conf.VCS = 'fab_deploy.vcs.'+vcs
+            env.conf.VCS = 'fab_deploy.vcs.' + vcs
 
 
 def virtualenv():
@@ -117,7 +139,7 @@ def virtualenv():
             # virtualenv is active here
 
     """
-    return prefix('source '+env.conf['ENV_DIR']+'/bin/activate')
+    return prefix('source %s/bin/activate' % env.conf.ENV_DIR)
 
 def inside_virtualenv(func):
     """
@@ -134,6 +156,14 @@ def inside_virtualenv(func):
             return func(*args, **kwargs)
     return inner
 
+def inside_src(func):
+    @wraps(func)
+    def inner(*args, **kwargs):
+        with cd(env.conf.SRC_DIR):
+            with virtualenv():
+                return func(*args, **kwargs)
+    return inner
+
 def inside_project(func):
     """
     Decorator. Use it to perform actions inside project dir with
@@ -151,7 +181,7 @@ def inside_project(func):
     """
     @wraps(func)
     def inner(*args, **kwargs):
-        with cd(env.conf['SRC_DIR']):
+        with cd(env.conf.PROJECT_DIR):
             with virtualenv():
                 return func(*args, **kwargs)
     return inner
@@ -168,3 +198,20 @@ def print_env():
 def _data_path(fname):
     """Return the path to a data file of ours."""
     return os.path.join(os.path.split(__file__)[0], fname)
+
+def _project_path(name):
+    return os.path.join(env.conf.PROJECT_PATH, name)
+
+def _remote_project_path(name):
+    return posixpath.join(env.conf.PROJECT_DIR, name)
+
+def _pip_req_path(name):
+    if not name.endswith(('.txt', '.pip',)):
+        name += '.txt'
+    return posixpath.join(env.conf.PIP_REQUIREMENTS_PATH, name)
+
+def _config_template_path(name):
+    for dir in env.conf.CONFIG_TEMPLATES_PATHS:
+        path = os.path.join(dir, name)
+        if os.path.exists(path):
+            return path
